Hyrax 3D Latent Space Explorer

Loading Data...
Hyrax 3D Latent Space Explorer

### Controls & Data

- Move Camera: Left-click + drag for rotation. Right clik + drag for translation.
- Zoom: Scroll
- Select Points: Press the S key + Left-Click + Drag to draw a sqaure

Select Data File:
Color Points By:
Display Columns

Selection Mode: OFF
Reset Selection
Color Legend
Select Colormap
Color Range
Min: 0
Max: 100
Min Max
Selected Images